Skip to main content Crate blueprint_networking_agg_sig_gossip_extension Copy item path Source AggregationResult Result of the aggregation protocol AggregationState State of the aggregation protocol for a single round AggregatorSelector Simplified mechanism for selecting aggregators in a deterministic way based on public keys.
This approach ensures the selection is cryptographically tamper-resistant. CustomWeight A custom weight map implementation EqualWeight A simple equal-weight implementation ProtocolConfig Configuration for the aggregation protocol SignatureAggregationProtocol The main protocol for signature aggregation AggSigMessage Protocol message types for signature aggregation AggregationError Error types for the aggregation protocol DynamicWeight A dynamic weight scheme that can be either equal-weight or custom-weight MaliciousEvidence Evidence of malicious behavior ProtocolRound Protocol rounds for the signature aggregation protocol
This makes the protocol flow more explicit and easier to debug SignatureWeight Trait for weighting of participants in signature aggregation